'''*******************************************************************************
*** Programme solution du pousse seringue mesure de volume
******************************************************************************'''

'''************************************************
L'entete
****************************************************************'''

#Importation des packages de methodes
import esp_rgb_lcd_grove    # import des methodes lcd BackLight
import time                 # import des methodes de pause
from machine import Pin     # impirt des methodes de broches
from machine import ADC     # import des methodes ADC
import cmath                # import des methodes math
from cmath import pi        # import du package math de la constante pi

#Creation de l'objet lcd de LCD I2C BackLight
lcd = esp_rgb_lcd_grove.esp_afficheur_lcd()     # L'objet lcd est cr閼煎崘

#Initialisation de l'afficheur
lcd.__init__()                  # Initialisation du lcd
lcd.color(0, 255, 0)            # affichage en vert
lcd.clear()                     # lcd efface
time.sleep_ms(10)       
lcd.setCursor(3,0)              # centrage ligne 1
lcd.write("BIENVENUE")    
lcd.setCursor(0,1)              # centrage ligne 2
lcd.write("POUSSE SERINGUE")
time.sleep(2)                   # pause de l'閼煎崒ran d'accueil

# Creation des objets entrees analogiques
E_Pot = ADC(Pin(36))               # Creation de l'objet E_Pot comme etant la patte 36 de l'esp en entree analogique (S0 de la carte)
E_Pot.atten(ADC.ATTN_11DB)         # Application de la methode attenuation 11dB pour lire une tension entre 0 et 3.6V


# Creation des objets sorties

# Creation des objets entrees
E_BP = Pin(14,Pin.IN,Pin.PULL_DOWN) #Declaration d'une entree E_BP sur la broche 14 du micro(D4 de la carte)

# declarations des variables globales
V_Nini=0          # represente le nbre issu de la CAN au depart
V_Nfin=0          # represente le nbre issu de la CAN a la fin de l'injection
V_Delta=0         # represente le nbre ecart issu des CAN
C_Deltamax=10     # represente la course max du curseur en cm
C_Vref=3.6        # represente vref de la CAN
V_Distance=0.0    # represente la distance parcourue par le curseur de pot
V_Ualimmax=3.3    # represente la tension max sur le pot
V_Vol=0.0         # represente le volume injecte par le seringue
C_R=0.006         # represente le rayon de la seringue selectionnee


'''****************************************************************
Les fonctions
****************************************************************'''
def mesure():
  V_Ntot=0                      # represente le cumul des acquisition
  for i in range (20):          # faire 20 fois l'acquisition et renvoi la moyenne
    V_N = E_Pot.read()          # acquisition CAN pot
    print("V_N=",V_N)         
    time.sleep_ms(10)
    V_Ntot = V_Ntot + V_N       # cumul des CAN
  return V_Ntot/20              # fait la moyenne de 20 acquisitions

''' ************************************************************
Le corps du programme
*************************************************************'''
while True:
  lcd.clear()                     # efface l'affichage
  time.sleep_ms(1)
  lcd.setCursor(0,0)              
  lcd.write("Mesure initiale:")   # affichage de l'action en cours
  time.sleep(1)
  V_Nini=mesure()                 # mesure de la position initiale
  print("V_Nini=",V_Nini)
  time.sleep(1)
  lcd.setCursor(0,1)
  lcd.write("Pressez seringue")   # affichage de demande d'action
  time.sleep(1)
  V_N=0
  while (V_N<(V_Nini+200)):       # tant que le piston ne bouge pas on attend
    V_N = E_Pot.read()
    time.sleep_ms(1)
  V_Nfin = V_Nini                 # le piston bouge, initialisation de la valeur mini de finale
  V_Nmem = 0
  while (V_Nmem<V_Nfin):          # tant que le piston est presse
    V_Nmem = V_Nfin
    V_Nfin = mesure()
    print("V_Nfin=",V_Nfin)
    print("V_Nmem=",V_Nmem)
    V_Distance=(C_Deltamax*C_Vref/(V_Ualimmax*4095))*(V_Nfin-V_Nini)    # calcul de la distance relative
    V_Vol=pi*(C_R**2)*V_Distance*0.1*100000                             # calcul du volume
    V_Vol=round(V_Vol,2)          # arrondi du volume
    V_Distance=round(V_Distance,2)# arrondi de la distance
    lcd.setCursor(0,0)            # mise a jour en direct de la distance
    lcd.write("Distance:")
    lcd.write(V_Distance)
    lcd.write("cm")
    lcd.setCursor(0,1)            # mise a jour en direct du volume injecte
    lcd.write("Volume:")
    lcd.write(V_Vol)
    lcd.write("ml")
    time.sleep_ms(10)
  lcd.setCursor(0,1)              # le piston ne bouge plus
  lcd.write("Injection=")         # affichage du volume definitif
  lcd.write(V_Vol)
  lcd.write("ml")
  while E_BP.value()==0:          # on attend l'ordre d'une nouvelle injection
    time.sleep_ms(1)
  while E_BP.value()==1:          # on recommence qd le soignant lache le BP
    time.sleep_ms(1)





